# py2to3cov
![release](https://img.shields.io/github/package-json/v/do-py-together/py2to3cov?label=release&logo=release&style=flat-square)
![build](https://img.shields.io/github/workflow/status/do-py-together/py2to3cov/test?style=flat-square)
![coverage](https://img.shields.io/codecov/c/github/do-py-together/py2to3cov?style=flat-square)
![dependencies](https://img.shields.io/librariesio/release/pypi/py2to3cov?style=flat-square)

Python 2/3 compatibility tool. Provide measurements on Python 3 incompatible code similar to coverage reports.

### Testing & Code Quality
Code coverage reports for master, branches, and PRs 
are posted [here in CodeCov](https://codecov.io/gh/do-py-together/py2to3cov).
